@@ -4,8 +4,8 @@ const style = require('.');
 const width = 55;
 let lineLength = 0;
 
-for (const [key, val] of Object.entries(style)) {
-	let code = val.open;
+for (const [key, value] of Object.entries(style)) {
+	let code = value.open;
 	let projectedLength = lineLength + key.length + 1;
 
 	if (key === 'reset' || key === 'hidden' || key === 'grey' || key.includes('Bright')) {
